import {
  select,
  geoPath,
  geoCentroid,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  scaleSqrt,
  max,
  schemeSpectral,
  format
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { sizeLegend } from './sizeLegend';
const svg = select('svg');


const width = +svg.attr('width');
const height = +svg.attr("height");

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const radiusValue = d => d.properties['2020'];

const g = svg.append('g');

const colorLegendG = svg.append('g')
	.attr('transform', `translate(50, 300)`);
const populationFormat = format(',');

svg.call(zoom().on('zoom', () => {
		g.attr('transform', event.transform);
	}));

g.append('path')
  .attr('class', 'sphere')
  .attr('d', pathGenerator({type: 'Sphere'}))


loadAndProcessData().then(countries => {
	const sizeScale = scaleSqrt()
    .domain([0, max(countries.features, radiusValue)])
    .range([0, 30])
 


  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => d.properties['2020']? '#c4c9c9' : '#edd3d3')
    .append('title')
      .text(d => isNaN(radiusValue(d))
            ? 'Missing data'
            : d.properties['Region, subregion, country or area *'] + ': ' + populationFormat(radiusValue(d)));
  
  countries.featuresWithPopulation.forEach(d => {
  	d.properties.projected = projection(geoCentroid(d));
  });
  
  
	g.selectAll('circle').data(countries.featuresWithPopulation)
    .enter().append('circle')
      .attr('class', 'country-cirlce')
  		.attr('cx', d => d.properties.projected[0])
  		.attr('cy', d => d.properties.projected[1])
  		.attr('r', d => sizeScale(radiusValue(d)))
  		.append('title')
     		.text(d => isNaN(radiusValue(d))
            ? 'Missing data'
            : d.properties['Region, subregion, country or area *'] + ': ' + populationFormat(radiusValue(d)));
  
  
  g.append('g')
    .attr('transform', `translate(30,240)`)
    .call(sizeLegend, {
      sizeScale,
      spacing: 40,
      textOffset: 50,
      numTicks: 5,
    	tickFormat: populationFormat
  })
  	.append('text')
  		.text('Population')
  		.attr('y', -50)
  		.attr('x', -30)
  		.attr('class', 'legend-title');
});